@@ -2,22 +2,28 @@ OC.L10N.register(
     "bookmarks",
     {
     "Bookmarks" : "Zaznamki",
-    "Not allowed to access folder to import into" : "Dostop do mape za uvoz ni dovoljen",
-    "Failed to import one bookmark, because: " : "Uvoz izbranega zaznamka je spodletel:",
     "No file provided for import" : "Ni navedenih datotek za uvoz",
     "Unsupported file type for import" : "Nepodprta vrsta datoteke za uvoz",
     "A Bookmark manager for Nextcloud" : "Upravljalnik zaznamkov za Nextcloud",
+    "Select bookmark" : "Izbor zaznamka",
     "Details" : "Podrobnosti",
     "Rename" : "Preimenuj",
     "Move" : "Premakni",
     "Delete" : "Izbriši",
     "Enter bookmark title" : "Naslov zaznamka",
     "Save" : "Shrani",
+    "No bookmarks here" : "Ni še dodanih zaznamkov.",
     "Select one or more tags" : "Izbor enega oziroma več zaznamkov",
     "New folder" : "Nova mapa",
+    "Grid view" : "Mrežni pogled",
+    "List view" : "Seznamski pogled",
+    "Move selection" : "Premakni izbor",
+    "Delete selection" : "Izbriši izbor",
     "Enter a link" : "Vnesite povezavo",
     "Create" : "Ustvari",
+    "Cancel" : "Prekliči",
     "Enter folder title" : "Vnesite naziv mape",
+    "Public" : "Javno",
     "Root folder" : "Korenska mapa",
     "New Bookmark" : "Nov zaznamek",
     "All Bookmarks" : "Vsi zaznamki",
@@ -32,16 +38,26 @@ OC.L10N.register(
     "Last modified" : "Nazadnje spremenjeno",
     "RSS Feed" : "Vir RSS",
     "Clear data" : "Počisti podatke",
+    "Permanently remove all bookmarks from your account. There is no going back!" : "Trajno odstrani vse zaznamke, povezane z računom. Dejanja ni mogoče povrniti!",
     "Delete all bookmarks" : "Izbriši vse zaznamke",
+    "Bookmarklet" : "Program za zaznamke",
     "Add to {instanceName}" : "Dodaj {instanceName} ",
     "Client apps" : "Odjemalski programi",
     "Do you really want to delete all your bookmarks?" : "Ali res želite izbrisati vse zaznamke?",
+    "URL" : "Naslov URL recepta",
     "Creation date" : "Datum ustvarjanja",
     "Tags" : "Oznake",
     "Select tags are create new ones" : "Izbor oznak in ustvarjanje novih",
     "Notes" : "Opombe",
     "Sharing" : "Souporaba",
     "{time} ago" : "pred {time}",
+    "Owner" : "Lastnik",
+    "Select a user or group" : "Izbor imena uporabnika oziroma skupine",
+    "Share link" : "Povezava za souporabo",
+    "Copy link" : "Kopiraj povezavo",
+    "Allow editing" : "Dovoli urejanje",
+    "Remove share" : "Odstrani souporabo",
+    "Link copied" : "Povezava je kopirana",
     "Select" : "Izbor",
     "Previews" : "Predogledi",
     "Screeenly" : "Screeenly",
@@ -55,7 +71,7 @@ OC.L10N.register(
     "This URL is already bookmarked! Overwrite?" : "Ta naslov URL je že dodan med zaznamke. Ali ga želite prepisati?",
     "Title" : "Naslov",
     "Link" : "Povezava",
-    "Enter bookmark url" : "Naslov URL zaznamka",
+    "Enter bookmark URL" : "Naslov URL zaznamka",
     "Failed to find existing bookmark" : "Dostop do obstoječega zaznamka je spodletel",
     "Failed to create bookmark" : "Ustvarjanje zaznamka je spodletelo",
     "Failed to save bookmark" : "Shranjevanje zaznamka je spodletelo",
@@ -66,9 +82,9 @@ OC.L10N.register(
     "Failed to delete folder" : "Brisanje mape je spodletelo",
     "Failed to create folder" : "Ustvarjanje mape je spodletelo",
     "Failed to move parts of selection" : "Premikanje delov izbire je spodletelo",
+    "Failed to delete parts of selection" : "Brisanje dela izbora je spodletelo",
     "Failed to fetch bookmarks." : "Pridobivanje zaznamkov je spodletelo",
     "Failed to change setting" : "Spreminjanje nastavitev je spodletelo",
-    "Failed to load setting " : "Nalaganje nastavitev je spodletelo",
     "Bookmarks feed" : "Vir zaznamkov"
 },
 "nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
